//plugin.c:

/*
 *      Copyright (C) Philipp 'ph3-der-loewe' Schafft - 2012-2013
 *
 *  This file is part of SavannahIce,
 *  a protocol converter between RoarAudio and Icecast.
 *  See README for details.
 *
 *  This file is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License version 3
 *  as published by the Free Software Foundation.
 *
 *  RoarAudio is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this software; see the file COPYING.  If not, write to
 *  the Free Software Foundation, 51 Franklin Street, Fifth Floor,
 *  Boston, MA 02110-1301, USA.
 *
 */

#include "savannahice.h"

#define HOST_NAME "SavannahIce"
#define HOST_API  NULL

savannahice_plugin_t savannahice_plugin_new(void) {
 savannahice_plugin_t ret;
 int err;

 ret = roar_plugincontainer_new_simple(HOST_NAME, HOST_API);
 if ( ret == NULL )
  return NULL;

 if ( roar_plugincontainer_set_autoappsched(ret, 1) == -1 ) {
  err = roar_error;
  savannahice_plugin_unref(ret);
  roar_error = err;
  return NULL;
 }

 return ret;
}

int savannahice_plugin_load(savannahice_plugin_t self, const char * name, const char * argv) {
 struct roar_dl_librarypara * para;
 int ret;
 int err;

 if ( self == NULL || name == NULL ) {
  roar_err_set(ROAR_ERROR_FAULT);
  return -1;
 }

 if ( argv == NULL ) {
  para = NULL;
 } else {
  para = roar_dl_para_new(argv, NULL, HOST_NAME, HOST_API);
  if ( para == NULL )
   return -1;
 }

 ret = roar_plugincontainer_load(self, name, para);
 err = roar_error;

 if ( para != NULL )
  roar_dl_para_unref(para);

 roar_err_set(err);
 return ret;
}

//ll
